@@ -410,6 +410,22 @@ class LineCurve(Curve):
             raise NotImplementedError(f"Close circuit not implemented for type [{type(self)}]")
         return next_point
 
+    def point_at_t(self, t: float):
+        if not (0 <= t <= 1):
+            raise ValueError(f"t must be between 0 and 1 but {t} was provided")
+
+        line_vector = self.end_point - self.origin
+        t_vector = line_vector * t
+
+        return self.origin + t_vector
+
+    def derivative_at_t(self, t: float):
+        if not (0 <= t <= 1):
+            raise ValueError(f"t must be between 0 and 1 but {t} was provided")
+
+        line_vector = self.end_point - self.origin
+
+        return line_vector.y / line_vector.x
 
 class CubicBezier(Curve):
     @classmethod
