@@ -1,19 +1,26 @@
 from typing import List, Callable, Any
 
 class Toggleable():
-    def __init__(self, values: List, starting_index: int = 0):
+    def __init__(self,
+                 values: List,
+                 starting_index: int = 0,
+                 on_toggle_callbacks: List[Callable[[], Any]] = None):
         # TODO: Values is better as a generator. This allows for user to provide an "infinite" list and not provide all values to memory
         self.values = values
         self.index = starting_index
+        self.on_toggle_callbacks = on_toggle_callbacks
 
-    def toggle(self, on_toggle_callback: Callable[[Any], Any] = None):
+    def toggle(self, on_toggle_callbacks: List[Callable[[Any], Any]] = None):
         self.index += 1
 
         if self.index >= len(self.values):
             self.index = 0
 
-        if on_toggle_callback is not None:
-            on_toggle_callback()
+        if self.on_toggle_callbacks is not None:
+            [x(self.value) for x in self.on_toggle_callbacks]
+
+        if on_toggle_callbacks is not None:
+            [x(self.value) for x in on_toggle_callbacks]
 
         return self.value
 
@@ -34,13 +41,14 @@ class Toggleable():
         self.index = self.values.index(value)
 
 class BooleanToggleable(Toggleable):
-    def __init__(self, default: bool = True):
+    def __init__(self, default: bool = True,
+                 on_toggle_callbacks: List[Callable[[Any], Any]] = None):
         if default:
             index = 1
         else:
             index = 0
 
-        Toggleable.__init__(self, [False, True], index)
+        Toggleable.__init__(self, [False, True], index, on_toggle_callbacks)
 
     @property
     def is_on(self):
@@ -77,9 +85,18 @@ class BooleanToggleable(Toggleable):
         else:
             return False
 
+    def __eq__(self, other):
+        if type(other) == type(BooleanToggleable):
+            return other.value == self.value
+        elif type(other) == bool:
+            return other == self.value
+
 class IntegerRangeToggleable(Toggleable):
-    def __init__(self, min: int, max: int, step_size: int = 1):
-        Toggleable.__init__(self, [ii for ii in range(min, max+1, step_size)])
+    def __init__(self, min: int, max: int, step_size: int = 1,
+                 on_toggle_callbacks: List[Callable[[Any], Any]] = None):
+        Toggleable.__init__(self,
+                            values=[ii for ii in range(min, max+1, step_size)],
+                            on_toggle_callbacks=on_toggle_callbacks)
 
         self.min = min
         self.max = max
@@ -90,8 +107,8 @@ class IntegerRangeToggleable(Toggleable):
         return type(self)(min=self.min, max=self.max, step_size=self.step)
 
 class EnumToggleable(Toggleable):
-    def __init__(self, enum_type, default=None):
+    def __init__(self, enum_type, default=None, on_toggle_callbacks: List[Callable[[Any], Any]] = None):
         self.enum = enum_type
-        Toggleable.__init__(self, [val for val in enum_type.__members__.values()], 0)
+        Toggleable.__init__(self, [val for val in enum_type.__members__.values()], 0, on_toggle_callbacks)
         if default is not None:
             self.set_value(default)
\ No newline at end of file
